# Boundaries API

Complete API reference for boundary conditions in Prismo.

## PML Absorbing Boundaries

### CPML

```{eval-rst}
.. autoclass:: prismo.boundaries.pml.CPML
   :members:
   :undoc-members:
   :show-inheritance:
```

### PMLParams

```{eval-rst}
.. autoclass:: prismo.boundaries.pml.PMLParams
   :members:
   :undoc-members:
   :show-inheritance:
```

## Mode Port Boundaries

### ModePort

```{eval-rst}
.. autoclass:: prismo.boundaries.mode_port.ModePort
   :members:
   :undoc-members:
   :show-inheritance:
```

### ModePortConfig

```{eval-rst}
.. autoclass:: prismo.boundaries.mode_port.ModePortConfig
   :members:
   :undoc-members:
   :show-inheritance:
```

## See Also

- {doc}`../user_guide/boundaries` - Boundary conditions guide
- {doc}`../user_guide/mode_ports` - Mode ports guide
- {doc}`../tutorials/waveguide_coupling` - Using mode ports in simulations

